tonalitytools.chord_class_extent_to_cardinality
===============================================

.. autofunction:: abjad.tools.tonalitytools.chord_class_extent_to_cardinality.chord_class_extent_to_cardinality
